==> summerd-sdk-1.1.19.tgz: package/config/webpack.prod.config.js <==
const webpack = require('webpack')
const merge = require('webpack-merge')
const webpackBase = require('./webpack.base.config')
const { projectPath } = require('../utils')
const WorkboxPlugin = require('workbox-webpack-plugin')
const appConfig = require('../utils/get-app-config')
const OptimizeCSSAssetsPlugin = require('optimize-css-assets-webpack-plugin')
const MiniCssExtractPlugin = require('mini-css-extract-plugin')
const cleanWebpackPlugin = require('clean-webpack-plugin')

// const rules = [...webpackBase.module.rules]
// console.log(rules)

const config = merge(webpackBase, {
  mode: 'production',
  output: {
    filename: '[name]_[hash:6].js',
    path: `${projectPath}/${appConfig.deploy ? appConfig.deploy.project : 'public'}`,
  },
  plugins: [
    new MiniCssExtractPlugin({
      // Options similar to the same options in webpackOptions.output
      // both options are optional
      filename: '[name].css',
      chunkFilename: '[id].css'
    }),
    new webpack.DefinePlugin({
      'process.env': {
        NODE_ENV: '"production"',
      },
    }),
    new WorkboxPlugin.GenerateSW({
      // 这些选项帮助 ServiceWorkers 快速启用
      // 不允许遗留任何“旧的” ServiceWorkers
      clientsClaim: true,
      skipWaiting: true
    }),
  ],
  optimization: {
    minimizer: [
      new MiniCssExtractPlugin({
        filename: 'css/app.[name].css',
        chunkFilename: 'css/app.[contenthash:12].css'  // use contenthash *
      })
    ],
  },
})

// 增加清除dir命令
if (appConfig.webpack.cleanDir && appConfig.webpack.cleanDir.length) {
  let dirs = [...appConfig.webpack.cleanDir]
  config.plugins.push(
    new cleanWebpackPlugin(dirs, {
      root: projectPath,
    })
  )
}

module.exports = config

==> summerd-sdk-1.1.22.tgz: package/config/webpack.prod.config.js <==
const webpack = require('webpack')
const merge = require('webpack-merge')
const webpackBase = require('./webpack.base.config')
const { projectPath } = require('../utils')
const WorkboxPlugin = require('workbox-webpack-plugin')
const appConfig = require('../utils/get-app-config')
const OptimizeCSSAssetsPlugin = require('optimize-css-assets-webpack-plugin')
const MiniCssExtractPlugin = require('mini-css-extract-plugin')
const cleanWebpackPlugin = require('clean-webpack-plugin')

const config = merge(webpackBase, {
  mode: 'production',
  output: {
    filename: '[name]_[hash:6].js',
    path: `${projectPath}/${appConfig.deploy ? appConfig.deploy.project : 'public'}`,
  },
  plugins: [
    new MiniCssExtractPlugin({
      filename: 'css/[name].css',
      chunkFilename: 'css/app.[contenthash:12].css',
    }),
    new webpack.DefinePlugin({
      'process.env': {
        NODE_ENV: '"production"',
      },
    }),
    new WorkboxPlugin.GenerateSW({
      // 这些选项帮助 ServiceWorkers 快速启用
      // 不允许遗留任何“旧的” ServiceWorkers
      clientsClaim: true,
      skipWaiting: true
    }),
  ],
  optimization: {
    runtimeChunk: {
      name: 'manifest',
    },
    minimize: true,
    splitChunks: {
      cacheGroups: {
        styles: {
          name: 'styles',
          test: /.css$/,
          chunks: 'all',
          enforce: true,
        },
      },
    },
  },
})

// 增加清除dir命令
if (appConfig.webpack.cleanDir && appConfig.webpack.cleanDir.length) {
  let dirs = [...appConfig.webpack.cleanDir]
  config.plugins.push(
    new cleanWebpackPlugin(dirs, {
      root: projectPath,
    })
  )
}

module.exports = config
